package main

import (
	"os"

	"gitlab161.poland.asseco.corp/cyfrowagranica/tools/multisql/cfg"
	"gitlab161.poland.asseco.corp/cyfrowagranica/tools/multisql/mgr"

	"log"
)

func main() {
	log.SetFlags(log.LstdFlags)
	params := cfg.GetParams()

	if params.LogFile != "" {
		fh, err := os.OpenFile(params.LogFile, os.O_CREATE|os.O_WRONLY|os.O_APPEND, 0o664)
		if err != nil {
			log.Fatalf("Nie udało się ustawić logu: %v", err)
		}
		defer fh.Close()
		log.SetOutput(fh)
	}

	if params.Verbose {
		log.Print("MultiSQL - start")
	}
	config, err := cfg.GetConfig(params)

	if err != nil {
		log.Fatalf("Błąd z konfiguracją: %v\n", err)
	}


	if params.OutDir == "" {
		params.OutDir = "."
	} else {
		fs, err := os.Stat(params.OutDir)
		if err != nil {
			log.Fatalf("Podany katalog wyników nie jest prawidłowy: %v\n", err)
		}
		if !fs.IsDir() {
			log.Fatalf("Ścieżka %s nie wskazuje na poprawny katalog\n", params.OutDir)
		}
	}

	manager, err := mgr.Create(params.Verbose, params.OutDir, config)
	if err != nil {
		log.Fatalf("Nie można wystartować operacji: %v\n", err)
	}

	err = manager.Run()

	if err != nil {
		log.Fatalf("Błąd przetwarzania: %v\n", err)
	}

}
